summaryrefslogtreecommitdiffstats
path: root/kmail/folderstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderstorage.h')
-rw-r--r--kmail/folderstorage.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kmail/folderstorage.h b/kmail/folderstorage.h
index 550b45e5..390675a2 100644
--- a/kmail/folderstorage.h
+++ b/kmail/folderstorage.h
@@ -245,10 +245,10 @@ public:
* be reflected in the UI. */
virtual bool isCloseToQuota() const;
/** Called by KMMsgBase::setqStatus when status of a message has changed
required to keep the number unread messages variable current. */
- virtual void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
- const KMMsgtqStatus newtqStatus,
+ virtual void msgStatusChanged( const KMMsgStatus oldStatus,
+ const KMMsgStatus newStatus,
int idx);
/** Open folder for access.
@@ -364,10 +364,10 @@ public:
void deregisterFromMessageDict();
/** Set the status of the message at index @p idx to @p status. */
- virtual void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
+ virtual void seStatus(int idx, KMMsgStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- virtual void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
+ virtual void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
void removeJobs();
@@ -245,10 +245,10 @@ public:
* be reflected in the UI. */
virtual bool isCloseToQuota() const;
- /** Called by KMMsgBase::setqStatus when status of a message has changed
+ /** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */